<p id="breadcrumb">

[Home](https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent) > Business Context > Business Data

</p>


# Business Data

The list of data elements, description and requirements that data providers adhere and data consumers may expect for DHDR data, can be found in the latest version of the DHDR Interface Specification.



## Query Parameters Data

The following table summarizes the mandatory and optional parameters for the query


**Mandatory Parameters:**


| Data Element       | Definition                                                                                                                                                                                                 | Example        |
|--------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------|
| Patient identifier | Only the 10 digit Ontario health card number (HCN) is allowed as an ID parameter in the current release. <br> <i>Note: HCN Version is not supported. DHDR uses Ontario HCN for unique identification of a patient while a version number is usually used for verification of the provincial coverage eligibility, which is out of scope for DHDR.</i>|3821694372   |


**Optional Parameters:**

| Data Element        | Definition                                                                                                                                                                                                                                              | Example                                              |
|---------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| whenHandedOver            | This parameter contains the dispense date of the substance. <br> <i>Note: If there is no lower limit in the search request, the server will use a configured default, e.g. 120 days back.     </i>                | gt2015-02-24                                          |
| Gender    | This parameter should contain the sex at birth as noted on the Ontario Health Card | male or female                                                |
| Birth Date | This parameter should contain the Date of Birth of the patient as on the Ontario Health Card                                                                                                                                  | 1929-11-29 |

<br>
<br>
<br>

##  DHDR Data Element to FHIR Element Mapping

**Patient**

|Data Field|Description|FHIR Resource Mapping
|-
|Patient First Name| First name of the patient|MedicationDispense.subject.Patient.name.given
|Patient Last Name|Last name of the patient|MedicationDispense.subject.Patient.name.family
|Patient Gender|Gender of the patient|MedicationDispense.subject.Patient.gender
|Patient Date of Birth|Date of birth of the patient|MedicationDispense.subject.Patient.birthDate
|Health Number|Number on an Ontario Health Card that uniquely identifies a patient|MedicationDispense.subject.Patient.identifier[1].value

**Medication**

|Data Field|Description|FHIR Resource Mapping
|-
|Drug Identification Number/Product Identification Number (DIN/PIN)| Drug Identification Number (DIN) assigned by Health Canada to every drug (e.g. Voltaren – DIN 00514012).                                                                  Product Identification Number (PIN) assigned by the Ministry of Health and Long-Term Care (MOHLTC) to some drugs.|MedicationDispense.medicationReference.Medication.code.coding[1].code
|Brand Name|Brand name or trade name of the prescription drug dispensed (e.g. Voltaren)|MedicationDispense.medicationReference.Medication.code.coding[1].display
|Generic Name|Non-proprietary name or generic name of the drug dispensed (e.g. diclofenac sodium)|MedicationDispense.medicationReference.Medication.code.coding[2].display
|Therapeutic Classification|Pharmacologic therapeutic classification of the prescription drug dispensed (e.g., analgesics nonsteroidal)|MedicationDispense.medicationReference.Medication.code.coding[3].display
|Therapeutic Sub-Classification|Pharmacologic therapeutic sub-classification of the prescription drug dispensed. (e.g. anti- inflammatory agent)|MedicationDispense.medicationReference.Medication.code.coding[4].display
|Strength|The amount of active ingredient in the prescription drug dispensed (e.g. 100mg)|MedicationDispense.medicationReference.Medication.extension[1].valueString
|Compound Indicator|Indicates that the drug product identified in the dispensed event was used to prepare a compounded medication|MedicationDispense.medicationReference.Medication.extension[2].valueBoolean
|Dosage Form|The physical form of a dose of a drug product (e.g., suppository)|MedicationDispense.medicationReference.Medication.form.text

**Practitioner Prescriber**

|Data Field|Description|FHIR Resource Mapping
|-
|Prescriber ID|License/registration number of the prescriber, issued by their licencing college|MedicationDispense.authorizingPrescription.MedicationRequest.requester.Practitioner.identifer.value
|Prescriber Issuing College|Identifies the registration authority (i.e. regulatory college – CPSO, RCDSO, etc.) which issued the license/registration number to the prescriber of the medication/pharmacy service|MedicationDispense.authorizingPrescription.MedicationRequest.requester.Practitioner.identifer.system  <br><br> The DHDR identifier system should be mapped to the college description in the "PrescriberID Reference Mapping" tab.
|Prescriber Name|First and last name of the prescriber that provided the prescription or ordered the pharmacy service|MedicationDispense.authorizingPrescription.MedicationRequest.requester.Practitioner.name.family <br><br> MedicationDispense.authorizingPrescription.MedicationRequest.requester.Practitioner.name.given
|Prescriber Phone Number|Phone number of the prescriber that provided the prescription or ordered the pharmacy service|MedicationDispense.authorizingPrescription.MedicationRequest.requester.Practitioner.telecom[1].value
|Prescriber Fax Number|Fax number of the prescriber that provided the prescription or ordered the pharmacy service|MedicationDispense.authorizingPrescription.MedicationRequest.requester.Practitioner.telecom[2].value

**Practitioner Dispenser**

|Data Field|Description|FHIR Resource Mapping
|-
|Pharmacist ID| License/registration number of the dispenser, issued by their licencing college|MedicationDispense.performer[2].actor.Practitioner.identifer.value
|Pharmacist Issuing College| Identifies the registration authority (i.e. regulatory college) which issued the license/registration number to the dispenser of the medication/pharmacy service. This is OCP in most cases, but may be CPSO in the case of a dispensing physician |MedicationDispense.performer[2].actor.Practitioner.identifer.system <br> The DHDR identifier system should be mapped to the college description in the "PrescriberID Reference Mapping" tab
|Pharmacist Name|First and last name of the pharmacist or dispensing physician that dispensed the prescription or rendered the pharmacy service <br> * Always available in NMS. Available in ODB if the pharmacist rendered a pharmacy service"|MedicationDispense.performer[2].actor.Practitioner.name.family <br> MedicationDispense.performer[2].actor.Practitioner.name.given 

**Organization**


|Data Field|Description|FHIR Resource Mapping
|-
|Pharmacy ID| Registration number of the dispensary which provided the medication/pharmacy service. Typically, for an accredited pharmacy, this will be the National Pharmacy ID Code, in alignment with the Canadian Pharmacists Association v3 claim standard. Will be a ministry assigned number for other dispensary locations (e.g. dispensing physicians)| MedicationDispense.performer[1].actor.Organization.identifier.value
|Pharmacy Issuing College| Identifies the registration authority (i.e. regulatory college) which issued the license/registration number to the dispensary which provided the medication/pharmacy service - this is OCP in most cases |MedicationDispense.performer[1].actor.Organization.identifier.system (Fixed to URI of Ontario College of Pharmacists Pharmacy ID: https://fhir.infoway-inforoute.ca/NamingSystem/ca-on-pharmacy-id-ocp)
|Pharmacy Name|Name of the pharmacy that dispensed the prescription or rendered the pharmacy service|MedicationDispense.performer[1].actor.Organization.name
|Pharmacy Phone Number|Phone number of the pharmacy that dispensed the prescription or rendered the pharmacy service|MedicationDispense.performer[1].actor.Organization.telecom[1].value
|Pharmacy Fax Number|Fax number of the pharmacy that dispensed the prescription or rendered the pharmacy service|MedicationDispense.performer[1].actor.Organization.telecom[2].value

**Medication Request**

|Data Field|Description|FHIR Resource Mapping
|-
|Original Rx Number |Number assigned by EMR or ePrescribing system to a new prescription on the original date of prescription|MedicationDispense.authorizingPrescription.MedicationRequest.identifier.value
|Original Rx Number System |Source system of the original Rx Number (e.g EMR, PMS or ePrescribing)|MedicationDispense.authorizingPrescription.MedicationRequest.identifier.system
|Medical Condition / Reason for Use |Indicates prescriber’s designation of the medical condition for which the patient is being treated. This data field is only available for Limited Use products (e.g. Acarbose, Aflibercept)|MedicationDispense.authorizingPrescription.MedicationRequest.reasonCode.coding.code <br><br> MedicationDispense.authorizingPrescription.MedicationRequest.reasonCode.coding.display

**Medication Dispense**

|Data Field|Description|FHIR Resource Mapping
|-
|Refills Remaining| Total number of refills remaining on a prescription|MedicationDispense.extension[1].valueInteger
|Quantity Remaining|Total quantity remaining on a prescription|MedicationDispense.extension[2].valueQuantity.value <br><br> MedicationDispense.extension[2].valueQuantity.unit 
|Current Prescription Number|The number assigned by the pharmacy that appears on the label of the dispensed prescription|MedicationDispense.identifer.value
|Quantity|Quantity of medication dispensed|MedicationDispense.quantity.value <br><br> MedicationDispense.quantity.unit
|Estimated Days Supply|Estimated number of days of treatment based on the directions for use on the prescription and/or the pharmacist’s judgment on usage|MedicationDispense.daysSupply.value
|Dispensed Date|Transaction date when the prescription drug was dispensed or the pharmacy service was rendered|MedicationDispense.whenPrepared
|Last Pickup Date|Date when the last dispensed product was provided to the patient|MedicationDispense.whenHandedOver
|Dosage Specification|Free text dosage instructions|MedicationDispense.dosageInstruction.text
|Patient Dosage Instruction|The instructions to the patient on how to take the medication (e.g. with food)|MedicationDispense.dosageInstruction.patientInstruction
|Frequency|The frequency with which the medication is to be taken (e.g., once a day, twice a day, every six hours)|MedicationDispense.dosageInstruction.timing.repeat.frequency <br><br> MedicationDispense.dosageInstruction.timing.repeat.period <br><br> MedicationDispense.dosageInstruction.timing.repeat.periodMax <br><br> MedicationDispense.dosageInstruction.timing.repeat.periodUnit
|PRN Indicator|An indicator that the medication is to be taken “as needed”|MedicationDispense.dosageInstruction.asNeededBoolean
|Route|The route by which a drug is administered to the patient (e.g., oral, inhalation, transdermal, injectable, rectal)|MedicationDispense.dosageInstruction.route.text
|Dose|The dose of the medication to be administered or taken by the patient (e.g. two capsules)|MedicationDispense.dosageInstruction.doseAndRate.doseQuantity.value <br><br> MedicationDispense.dosageInstruction.doseAndRate.doseQuantity.unit


### Prescriber ID Reference Mapping

|HNS Code|FHIR Practitioner.Identifer.System|Description
|-
|01|ca-on-license-physician|The College of Physicians and Surgeons of Ontario
|02|ca-on-license-dental-surgeon|Royal College of Dental Surgeons of Ontarioy
|03|ca-on-license-chiropodist|College of Chiropodists of Ontarior
|05|ca-out-of-province-prescriber|Out-of-Province Prescriber
|08|ca-on-license-midwife|College of Midwives of Ontario
|09|ca-on-license-pharmacist|Ontario College of Pharmacists
|43|ca-on-license-optometrist|College of Optometrists of Ontario
|44|ca-on-license-nurse|College of Nurses of Ontario
|NO|ca-on-license-naturopath|College of Naturopaths of Ontario
|99|ca-on-unknown-prescriber|Unknown Prescriber