# Identifier Policy


The DHDR project uses URIs whenever Object Identifiers are required. URIs (Uniform Resource Identifiers) are globally unique identifiers for individual objects, as well as for value sets, code systems, profiles, namespaces, and more. URIs are the preferred object identifiers for FHIR objects, and are usually represented as URLs. All OIDs and URIs used in eHealth Ontario projects must conform to eHealth Ontario’s OID and URI Management Policy

For more information, or to obtain the proper OIDs and URLs for use in this project, contact the eHealth Ontario Standards Team at architecture@ehealthontario.on.ca

These identifiers capture the URI specific to an implementation/environment, such as the URL for resources and extensions used in the DHDR solution.

The base URL for DHDR FHIR interface will be referred to as “[base]” in the sections and examples below. Please note that base URL might change over time.

The base URL for Naming System (namespace of identifiers and code system of local terminologies) is https://ehealthontario.ca/API/FHIR/NamingSystem.

For global/shareable identifiers (e.g. Ontario health care number, Ontario Physician License, etc.), this might be replaced with http://hl7.org/fhir/NamingSystem/ca-on-license-physician in the future when HL7 FHIR Naming System registry is available.

The base for global identifier namespaces will be referred to as "[id-system-global-base]" in the sections and examples below.

The base for local identifier namespaces (e.g. dispense identifiers, prescription numbers, etc.) will be referred to as “[id-system-local-base]” in the sections and examples below.

The base for local code systems (e.g. Ontario drug types) will be referred to as “[code-system-local-base]” in the sections and examples below.

Due to the evolving FHIR standard and its developing framework and governance, implementers should recognize that these identifiers may change if identifier registration becomes governed nationally or internationally. Implementers are recommended to implement URIs using configurable variables.


###### <B> Table 3 Identifier  </B>

Variable | Value |
|---|:---:|:-
| [base] |	https://wsgateway.prod.ehealthontario.ca/API/FHIR/Medications/v2/MedicationDispense |
| [base-structure]	| https://ehealthontario.ca/API/FHIR/StructureDefinition |
| [id-system-global-base] | https://ehealthontario.ca/API/FHIR/NamingSystem |
| [id-system-local-base] | https://ehealthontario.ca/API/FHIR/NamingSystem |
| [code-system-local-base]	| https://ehealthontario.ca/API/FHIR/NamingSystem | 

