<p id="breadcrumb">

[Home](https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent) > Implementation Guidance >  Implementation Consideration

</p>

# Conformance Rules

FHIR is a general purpose specification and imposes no particular requirements on implementers to support specific resources, operations, search parameters or other capabilities. To achieve interoperability in a particular domain, it's important that implementors make similar decisions about what FHIR capabilities those systems will support. FHIR uses the Conformance resource to define the actual or expected capabilities of a particular system.

# Implementation Consideration
Within DHDR, there is a broad range of concepts including patients, providers, organizations, systems, and medications that require accurate identification.

Identifiers relevant to this interface include:

•	**Organization Identifiers** and **Service Provider Identifiers** 

•	**Patient Identifier**  is used to identify the person and is issued by Service Ontario and referred to as the Ontario Health Card

•	**Terminology:** the various coded values which are used to describe clinical concepts within health records as well as codes used within messages to meet the structural requirements of interfaces.

## MustSupport Flag

To maximize interoperability, this implementation guide uses MustSupport flag to identify elements that implementers must understand in order to properly submit, process or view. Please refer to the guidance below:

### Receiving Record from DHDR

Elements marked with "MustSupport" will be supported in accordance with the definition in the profiles for the DHDR. Consuming applications SHALL be capable of processing resources containing MustSupport data elements without generating an error or causing the application to fail. Consuming applications SHOULD be capable of handling the MustSupport data elements in a meaningful way (e.g. store it, use it in subsequent workflow or business function), and SHALL be able to process instances containing MustSupport data elements asserting missing information. Elements without the "MustSupport" flag when receiving from DHDR might not be stored, viewed, or otherwise processed by the receiving application unless there is implementation guidance to indicate that the element is considered optional, in which case it should be displayed, stored, or otherwise processed if possible.

## Letter Case

Information in DHDR is stored as mixed case and information is preserved in the format provided by the source (e.g. ALL UPPER CASE, Mixed Case, or a mix).  DHDR consumers MAY apply data formatting rules where there is a local requirement to standardize information to a consistent format.

## Extended Character Set

Information within Ontario’s EHR assets includes UTF-8 to support extended characters beyond standard ASCII/ANSI character set including French characters.


## Data Type Notes

### Date.

A date, or partial date (e.g. just year or year + month) as used in human communication. There is no time zone. Dates SHALL be valid dates.

Regex: -?[0-9]{4}(-(0[1-9]|1[0-2])(-(0[0-9]|[1-2][0-9]|3[0-1]))?)?

Example:  1951-06-04


### DateTime



A date, date-time or partial date (e.g. just year or year + month) as used in human communication. If hours and minutes are specified, a time zone SHALL be populated. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored. Dates SHALL be valid dates. The time "24:00" is not allowed.

Regex: -?[0-9]{4}(-(0[1-9]|1[0-2])(-(0[0-9]|[1-2][0-9]|3[0-1])(T([01][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9](\.[0-9]+)?(Z|(\+|-)((0[0-9]|1[0-3]):[0-5][0-9]|14:00)))?)?)?


Example:  1951-06-04T10:57:34-05:00


### URI/UUID

Uniform Resource Identifiers (URIs) leveraged in the DHDR are case sensitive. URIs can be absolute or relative, and may have an optional fragment identifier. Universally Unique IDs (UUIDs) are defined in lower case format (e.g. “urn:uuid:53fefa32-fcbb-4ff8-8a92-55ee120877b7”).


### Slicing


One common feature of constraining Structure Definitions is to take an element that may occur more than once (e.g. in a list), and split the list into a series of sublists, each with different restrictions on the elements in the sublist with associated additional meaning. In FHIR®, this operation is known as "Slicing" a list. It is common to "slice" a list into sub-lists each containing just one element, effectively putting constraints on each element in the list. This technique can also be used on elements that do not repeat, but that have a choice of data types.
A number in the brackets after the element name refers to its slicing number.

## Logical ID

Each resource has an id element which contains the "logical id" of the resource assigned by the server responsible for storing it. Resources always have a known logical id except for a few special cases (e.g. when a new resource is being sent to a server to assign a logical id in the create interaction). The logical id is unique within the space of all resources of the same type on the same server. Once assigned by the server, the id is never changed.

The location of a resource instance is an absolute URI constructed from the server base address at which the instance is found, the resource type and the Logical ID, such as http://test.fhir.org/rest/Patient/123 (where 123 is the Logical Id of a Patient resource). When the location is an HTTP address, this address can generally be used to retrieve or manipulate the resource. Note that implementations SHOULD NOT assume that the location of a resource is always resolvable to an accessible server - it may be temporarily unavailable, or not available by policy (e.g. firewalls) or in some cases, it might not actually exist (e.g. use of resource outside a RESTful environment). Resources reference each other by their location. These references are allowed to be absolute or relative (see Resource References for further discussion).

When a resource is copied from one server to another server, the copy might or might not keep the same logical id on the new server. This depends on replication and server policy. For further details, see Managing Resource Identity (including "Consistent Resource Identification").

Logical ids (and therefore locations) are case sensitive. Logical Ids are always opaque, and external systems need not and should not attempt to determine their internal structure. A logical id SHALL always be represented in the same way in resource references and URLs. Ids can be up to 64 characters long, and contain any combination of upper and lowercase ASCII letters, numerals, "-" and ".".

In some contexts, resources are not associated with location on a RESTful server, either because they are only created transiently for transfer between systems, or the systems are not using RESTful servers. In these cases, resources may be assigned some kind of location anyway, for purposes of consistency, or they might not have an assigned logical id, and they are identified based on other kinds of identifiers. See Resolving references in Bundles for one method of using resources not associated with RESTful servers.

## Managing Search Parameters

This interaction searches a set of resources based on some filter criteria. The interaction can be performed by several different HTTP commands.

~~~~
GET [base]/[type]{?[parameters]{&_format=[mime-type]}}
~~~~

This searches all resources of a particular type using the criteria represented in the parameters.
All these search interactions take a series of parameters that are a series of name=value pairs encoded in the URL (See W3C HTML forms).
If the search fails (cannot be executed, not that there is no matches), the return value is a status code 4xx or 5xx with an OperationOutcome. If the search succeeds, the return content is a Bundle with type = searchset containing the results of the search as a list of resources in a defined order.

## Search Parameter Types

| Type  |Description   |Parameter Expression Structure| Example|
|---|---|
|  number | Search parameter SHALL be a number (a whole number, or a decimal).  |parameter =[comparator][number]|length=27// equal to 27 <br>length=27,28//equal to 27 or 28<br> length=lt27// less than 27 <br> length=le27.6 <br> length=gt27 <br>|
| date  | Search parameter is on a date/time. The date format is the standard XML format.  |parameter =[comparator] [date] |birthdate=2010-10-01 <br> birthdate=gt2010-10-01|
| string  | Search parameter is a simple string, like a name part. Search is case-insensitive and accent-insensitive. May match just the start of a string. String parameters may contain spaces.  | parameter=[value]| name=john <br> name=john,jack//john or jack|
| token  |  Search parameter on a coded element or identifier. May be used to search through the text, displayname, code and code/codesystem (for codes) and label, system and key (for identifier). Its value is either a string or a pair of namespace and value, separated by a pipe, depending on the modifier used. | parameter=[system][code]| reference=www.url.com/123|
| reference  |  Search parameter on a reference element. Allows identification of resources where a referenced resource matches the query ID.<br> Not used in the current release | parameter=[type]/[id]| requester=practitioner/123|

## Prefixes

For the ordered parameter types of number, date, and quantity, a prefix to the parameter value may be used to control the nature of the matching. To avoid URL escaping and visual confusion, the following prefixes are used:

###### <b>HL7 FHIR Search Parameters Modifiers</b>
| Prefix | Description | Details |
|----|---------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| eq | the value for the parameter in the resource is equal to the provided value | the range of the search value fully contains the range of the target value |
| gt | the value for the parameter in the resource is greater than the provided value |	the range above the search value intersects (i.e. overlaps) with the range of the target value |
| lt | the value for the parameter in the resource is less than the provided value |	the range below the search value intersects (i.e. overlaps) with the range of the target value |
| ge | the value for the parameter in the resource is greater or equal to the provided value | the range above the search value intersects (i.e. overlaps) with the range of the target value, or the range of the search value fully contains the range of the target value |
| le | the value for the parameter in the resource is less or equal to the provided value    | the range below the search value intersects (i.e. overlaps) with the range of the target value or the range of the search value fully contains the range of the target value  |

If no prefix is present, the prefix eq is assumed.
<br>

*Numeric Examples*

| Example    | Description                                                      |
|--------------------|-------------------------------------------------------------------------------------------------------------------------------------------|
| [parameter]=100    | Values that equal 100, to 3 significant figures precision, so range [99.5 ... 100.5)                                                      |
| [parameter]=100.00 | Values that equal 100, to 5 significant figures precision, so range [99.995 ... 100.005). Whole numbers also equal 100.00, but not 100.01 |
| [parameter]=le100  | Values that are less or equal to 100                                                                                                      |
| [parameter]=ge100  | Values that are greater or equal to 100  

<br>

*Date Range Examples*

To search for all medication dispenses in a patient compartment that occurred over a 2 year period:


~~~~

GET [base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678&whenhandedover=le2015-12-31
~~~~


To search for the number of medication dispenses between a period of time

~~~~

GET [base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678&whenhandedover=ge2015-02-24&whenhandedover=le2016-02-26&_summary=count

~~~~

To search for the number of medication dispenses between a period of time using date of birth and gender

~~~~

GET [base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678& patient.birthdate=1971-11-28&patient.gender=female&whenhandedover=ge2015-02-24&whenhandedover=le2016-02-26&_sort=-whenhandedover&_count=10

~~~~

# Paging

The server provides paging for the results of a search interaction, and conforms to method adapted from RFC 5005 (Feed Paging and Archiving)  for sending continuation links to the client when returning a Bundle.

This example shows the third page of a search result:


~~~~

<Bundle xmlns="http://hl7.org/fhir">
  <!-- snip metadata -->
  <!-- This Search url starts with base search, and adds the effective
    parameters, and additional parameters for search state. All searches
    SHALL return this value.

	  In this case, the search continuation method is that the server
    maintains a state, with page references into the stateful list.
	-->
  <link>
    <relation value="self">

    <url value="[base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678&whenhandedover=ge2015-02-24&whenhandedover=le2016-02-26&_sort=-whenhandedover&_count=10&search-id=76395924-28c2-4cb1-93c1-608fb6eea979&page=3"/>
  </link>

  <link>
    <relation value="next"/>
    <url value="[base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678&whenhandedover=ge2015-02-24&whenhandedover=le2016-02-26&_sort=-whenhandedover&_count=10&search-id=76395924-28c2-4cb1-93c1-608fb6eea979&page=4"/>
  </link>

  <!-- then the search results... -->
</Bundle>

~~~~

A server will inform the client of the total number of resources returned by the interaction for which the results are paged using the Bundle.total. Please refer to the "Bundle Example" section, which shows use of Total and to the text in “Bundle Resource” section, which provides detailed explanation of Total.

# Managing Returned Resources


In order to allow the client to be confident about what search parameters were used as criteria by the server, the server will return the parameters that were actually used to process the search. Applications processing search results SHALL check these returned values where necessary. For example, if the server did not support some of the filters specified in the search, a client might manually apply those filters to the retrieved result set, display a warning message to the user or take some other action.
In the case of a RESTful search, these parameters are encoded in the self link in the bundle that is returned:

~~~~
<link>
    <relation value="self"/>
     <url value="[base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678"/>
 </link>
~~~~

In other respects, servers have considerable discretion with regards to supporting search:

*	Server will declare additional parameter search-id in the profiles referenced from their conformance statements. This search-id will be generated for each search request, logged in audit database along with the search request & search response and returned to the client, who is expected to log this in their audit database too.
*	Parameter names and URLs are case-sensitive.
*	Server will choose how many results to return, though the client can use _count as described below.
* Server will choose how to sort the return results, though it will honor the _sort parameter.

## Sorting


The client can indicate which order to return the results by using the parameter _sort, which can have a value of one of the search parameters. The _sort parameter can repeat to indicate sort order, with the repeats indicating a lower sort priority sequentially. In the current release, only sorting by whenprepared (dispense date) is supported.
Each item in the comma separated list is a search parameter, optionally with a '-' prefix. The prefix indicates decreasing order; in its absence, the parameter is applied in increasing order. E.g.: sort=-whenprepared

**Note:**

*	The server returns the sort it performs as part of the returned search parameters (see below).
*	A search parameter can refer to an element that repeats, and therefore there can be multiple values for a given search parameter for a single resource. In this case, the sort is based on the item in the set of multiple parameters that comes earliest in the specified sort order when ordering the returned resources.
*	When sorting on string search parameters, sorting will be performed on a case-insensitive basis. Accents will be ignored.


## Page Count

In order to keep the load on clients, server and the network minimized, the server may choose to return the results in a series of pages. The search result set contains the URLs that the client uses to request additional pages from the search set. Page links are contained in the returned bundle as links.
Server will provide its own parameters in the links that it uses to manage the state of the search as pages are retrieved. These parameters do not need to be understood or processed by the client.
The parameter _count is defined as a hint to the server regarding how many resources should be returned in a single page. Server will not return more resources than requested, but is allowed to return less than the client requested. The server might define a configurable default and maximal values for count in the future release. The server will repeat the original _count parameter in its returned page links so that subsequent paging requests honor the original _count.
<b>Note</b>: The combination of _sort and _count can be used to return only the latest resource that meets a particular criteria - set the criteria, and then sort by date in descending order, with _count=1. This way, the last matching resource will be returned.


## Server Conformance

In order to allow the client to be confident about what search parameters were used as criteria by the server, the server will return the parameters that were actually used to process the search. Applications processing search results SHALL check these returned values where necessary. For example, if the server did not support some of the filters specified in the search, a client might manually apply those filters to the retrieved result set, display a warning message to the user or take some other action.
In the case of a RESTful search, these parameters are encoded in the self link in the bundle that is returned:

~~~~

<link>
    <relation value="self"/>
    <url value="[base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678"/>
  </link>


~~~~

In other respects, servers have considerable discretion with regards to supporting search:
*	Server will declare additional parameter search-id in the profiles referenced from their conformance statements. This search-id will be generated for each search request, logged in audit database along with the search request & search response and returned to the client, who is expected to log this in their audit database too.
*	Parameter names and URLs are case-sensitive.
*	Server will choose how many results to return, though the client can use _count as above.
*	Server will choose how to sort the return results, though it will honor the _sort parameter.