## Introduction

This DHDR FHIR specification defines the FHIR profiles (constraints) and extension elements that are used in the DHDR project. All FHIR-based specifications rely on an underlying set of base “resources”.

### <B> Resources </B>

Resources are the building blocks of the FHIR standard. These resources convey the content of clinical records, identify patients or providers, or otherwise support messaging between systems. These resources have been developed by several working groups at HL7, based on members’ experience and subject expertise. These resources are intended to capture and support 80% of all implementation use case requirements; projects are encouraged to
meet the remaining 20% of requirements through extensions and profile constraints. The list of all available resources in the FHIR standard can be found at https://hl7.org/fhir/resourcelist.html, with additional details at https://hl7.org/fhir/resourceguide.html.

### <B> Profiles </B>

Resources defined in the FHIR standard are intended to support a wide variety of use cases, resulting in a large number of available elements, and very few constraints. Implementers are encouraged to create and apply FHIR Profiles, which places constraints on the defined FHIR resources – tightening cardinality, identifying unused/unsupported elements, defining value sets for elements, and adding extension elements.

### <B> Transmission Specification </B>

The formal MIME-type for FHIR resources is application/fhir+json or application/fhir+xml. The correct mime type SHALL be used by clients and servers:
<ul> 
<li> JSON (preferred): application/fhir+json
<li> XML (optional): application/fhir+xml
</ul>

FHIR uses UTF-8 for all request and response bodies. Since the HTTP specification defines a default character encoding of ISO-8859-1, requests and responses SHALL explicitly set the character encoding to UTF-8 using the charset parameter of the MIME-type in the Content-Type header. Requests MAY also specify this charset parameter in the Accept header and/or use the Accept-Charset header.

<B>Accept-Language</B> field in HTTP header will be used to set the language of the search in the future releases. The allowed values are “en-CA” and “fr-CA”. If this field is not set by the requestor, the default is “en-CA”. In the current release, only “en-CA” is supported.