<p id="breadcrumb">

[Home](https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent) > Profiles and Operations > Medication Dispense Search

</p>


# Medication Dispense Search

MedicationDispense search is simple RESTful interactions. It supports retrieving dispenses handed over within a date range or on a specific date for a consumer by patient ID.

### Scope

This transaction involves a request by the following parameters:

**The mandatory parameters for the query:**
* Patient Health Card Number

**The optional parameters for the query:**

* Gender 
* Date of birth
* whenHandedOver (this should default to the dispense date)

### Ontario DHDR FHIR® Resources

The MedicationDispense resource contains several references to other resources, e.g. the originating prescription (MedicationRequest resource), the prescriber (Practitioner resource), the patient (Patient resource), etc. The diagram below illustrates the resources that are referenced by the MedicationDispense resource, which are contained in the DHDR MedicationDispense response.


{{tree:ca-on-dhdr-r4/dhdrmedicationdispensecontained}}
<B> Figure 1 Medication Dispense and Contained Resources </B>

### Specification

The FHIR DHDR specification is based on the HL7 FHIR R4 Search operation.  

**MedicationDispense Search Request**

The MedicationDispense Search Request is an HTTP GET operation with multiple query parameters specified in Supported Search Parameters section below. The syntax of the request is 


*GET [base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678& patient.birthdate=1971-11-28&patient.gender=female&whenprepared=ge2018-02-24&whenprepared=le2019-02-26&_sort=-whenprepared&_count=10*


**_Note: For more details please reference Supported Search Parameters and Medication Dispense Search Examples sections_**

<br>

#### <B> Transaction: <i>Search</i> Medication Dispense Query/Response </B>

###### <B> Medication Dispense Search </B>

The transactions will: 

<ul>

<li> Allow a client application to search the DHDR solution database for MedicationDispense records matching the search criteria
<li> Allow the DHDR solution to return an appropriate set of MedicationDispense records
</ul>


{{tree:ca-on-dhdr-r4/retrieve-medication-transaction-flow}}
<B> Figure 2 Search Medication Transaction </B>

<br>

#### <B> Transaction: <i>Retrieve</i> Medication Dispense Request/Response </B>

###### <B> Medication Dispense Retrieval </B>
<p>Medication Dispense Retrieval will fetch a specific Medication Dispense record from the DHDR solution database. </p>

The transactions will: 
<ul>
<li> Allow a client application to search the DHDR solution database for MedicationDispense records matching the search criteria
<li> Allow the DHDR solution to return an appropriate set of MedicationDispense records
</ul>

The medication dispensation record that is returned will contain the information about the type of medication dispensed, the prescriber, the fulfilling pharmacist and the name of the pharmacy that dispensed it.

{{tree:ca-on-dhdr-r4/read-medication-transation-flow}}
<B> Figure 3 Retrieve Medication Transaction </B>

<br> 

#### <B> Transaction: Create Temporary Consent Unblock for Medication Dispenses Blocked by Consent Directives </B>

###### <B> Consent Unblock Request </B> 

After receiving a Medication Dispense Response identifying the existence of records blocked by a consent directive, the user may request access to those blocked records by using the client application to send a Temporary Consent Unblock Request to the Gateway.  The request is submitted under the user’s “Under Authority Of” (UAO) organization and allows all users of the UAO organization access to the patient’s blocked  records for the subsequent four hours.


{{tree:ca-on-dhdr-r4/create-temporary-consent-block}}
<B> Figure 4 Create Temporary Consent Unblock </B>

<br>

**Medication Dispense Profiles**



* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionMedicationDispenseProfile.guide.md" target="_blank">Medication Dispense</a>

* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionMedicationProfile.guide.md" target="_blank"> Medication</a>


* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionMedicationRequestPrescriptionProfile.guide.md" target="_blank">Medication Request (Prescription) </a> 



* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionPatientProfile.guide.md" target="_blank">Patient (Demographic)</a>


* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionPractitionerPrescriberProfile-duplicate-2.guide.md" target="_blank">Practitioner (Prescriber)</a>

* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionPractitionerDispenserProfile.guide.md" target="_blank">Practitioner (Dispenser) </a>

* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionOrganizationDispensingPharmacyProfile.guide.md" target="_blank">Organization (Dispensing Pharmacy) </a>

* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionBundleProfile.guide.md" target="_blank">Bundle </a>


* <a href="https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent/ProfilesandOperations/StructureDefinitionOperationOutcomeProfile.guide.md" target="_blank">OperationOutcome </a>


## Extensions


* <a href="https://simplifier.net/ca-on-dhdr-r4/dispenseremainingquantity" target="_blank"> ca-on-medications-ext-quantity-remaining (Dispense Remaining Quantity Extension)</a>

* <a href="https://simplifier.net/ca-on-dhdr-r4/dispenseremainingrefills" target="_blank"> ca-on-medications-ext-refills-remaining (Dispense Remaining Refills Extension)</a>

* <a href="https://simplifier.net/ca-on-dhdr-r4/medicationstrength" target="_blank"> ca-on-medications-ext-medication-strength (Medication Strength Extension)</a>

* <a href="https://simplifier.net/ca-on-dhdr-r4/drugcompoundindicator" target="_blank"> ca-on-medications-ext-compound-indicator (Drug Compound Indicator Extension)</a>


<br>

### Supported Search Parameters

<br>

**GET MedicationDispense (query by Patient ID)**

Patient ID parameter: **patient.identifier**

Only Ontario health card number is allowed as an ID parameter in the current release.

* Example: `patient.identifier= [id-system-global-base]/ca-on-patient-hcn|12345678`

Optional Dates parameter: **whenhandedover**

* Example: `whenhandedover=ge2015-02-25&whenhandedover=le2016-02-27`

Optional Date of Birth and Gender parameter:  **patient.birthdate & patient.gender**

* Example: `patient.birthdate=1971-11-28&patient.gender=female`


<br>

Format: JSON (default) or XML

* Example: `format=[mime-type]:_format=application/ FHIR +json or _format=application/ FHIR + xml`

<br>

### Example

**Medication Dispense Search Example**

* Search by patient identifier & dates

`GET [base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678&whenprepared=ge2018-02-24&whenprepared=le2019-02-26&_sort=-whenprepared&_count=10`

<br>

In the returned Bundle, bundle.link (self) will contain an URL with a server-generated search-id value: `[base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678&whenprepared=ge2018-02-24&whenprepared=le2019-02-26&_sort=-whenprepared&_count=10&search-id=76395924-28c2-4cb1-93c1-608fb6eea979`
<br>

* Search with date of birth and gender

`GET [base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678& patient.birthdate=1971-11-28&patient.gender=female&whenprepared=ge2018-02-24&whenprepared=le2019-02-26&_sort=-whenprepared&_count=10`

<br>

* Get the count of records

`GET [base]/MedicationDispense?patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678&whenprepared=ge2018-02-24&whenprepared=le2019-02-26&_summary=count`

<br>

* Search using POST

`POST  [base]/MedicationDispense/_search?_count=10&_format=application/fhir+json
Content-Type: application/x-www-form-urlencoded
patient.identifier=[id-system-global-base]/ca-on-patient-hcn|12345678& patient.birthdate=1971-11-28&patient.gender=female&whenprepared=ge2018-02-24&whenprepared=le2019-02-26&_sort=-whenprepared`

<br>

**_Please note that “OperationOutcome Example - Consent" section provides an example of the OperationOutcome resource that would appear in a bundle if there are any records blocked due to a consent directive._**

<br>

**_Examples of a search response can be found below_**


| Resource | Example        |                                                                                      
---------------|-----------------------|
| Medication          |  <a href="https://simplifier.net/ca-on-dhdr-r4/medicationexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/medicationexample/~json" target="_blank"> JSON</a>                | 
| Medication Dispense       |  <a href="https://simplifier.net/ca-on-dhdr-r4/medicationdispense-example" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/medicationdispense-example/~json" target="_blank"> JSON</a>          |  
| Bundle (Medication Dispense Contained Resources)        |  <a href="https://simplifier.net/ca-on-dhdr-r4/medicationdispensecontainedexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/medicationdispensecontainedexample/~json" target="_blank"> JSON</a>          |      
| Bundel (Medication Dispense <u>without</u> Contained Resources)         |  <a href="https://simplifier.net/ca-on-dhdr-r4/medicationdispenseoperationexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/medicationdispenseoperationexample/~json" target="_blank"> JSON</a>         |   
| Medication Request (Prescription)         |   <a href="https://simplifier.net/ca-on-dhdr-r4/medicationrequestexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/medicationrequestexample/~json" target="_blank"> JSON</a>          |                        
| Organization (Dispensing Pharmacy)         | <a href="https://simplifier.net/ca-on-dhdr-r4/organizationdispensingpharmacyexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/organizationdispensingpharmacyexample/~json" target="_blank"> JSON</a>          |                        
| Patient        |  <a href="https://simplifier.net/ca-on-dhdr-r4/patientexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/patientexample/~json" target="_blank"> JSON</a>          |                        
| Practitioner (Prescriber)         |   <a href="https://simplifier.net/ca-on-dhdr-r4/practitionerprescriberexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/practitionerprescriberexample/~json" target="_blank"> JSON</a>          |                        
| Practitioner (Dispensing Pharmacist)         |  <a href="https://simplifier.net/ca-on-dhdr-r4/practitionerdispenserexample" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/practitionerdispenserexample/~json" target="_blank"> JSON</a>          |  
| Bundle       |  <a href="https://simplifier.net/ca-on-dhdr-r4/bundlesearch-example" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/bundlesearch-example/~json" target="_blank"> JSON</a>          |     
| OperationOutcome       |  <a href="https://simplifier.net/ca-on-dhdr-r4/operationoutcomesearch-example" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/operationoutcomesearch-example/~json" target="_blank"> JSON</a>          |     
| OperationOutcome  (Consent Block)      |  <a href="https://simplifier.net/ca-on-dhdr-r4/operationoutcomeconsent-example" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/operationoutcomeconsent-example/~json" target="_blank"> JSON</a>          | 
| OperationOutcome (Temporary Consent Unblock)      |  <a href="https://simplifier.net/ca-on-dhdr-r4/operationoutcomeconsentunblock-example" target="_blank"> XML</a> / <a href="https://simplifier.net/ca-on-dhdr-r4/operationoutcomeconsentunblock-example/~json" target="_blank"> JSON</a>          |                 
