<p id="breadcrumb">

[Home](https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent) > Capability Statement > Response Handling

</p>


# Errors

## HTTP Response Codes

This specification makes rules about the use of specific HTTP status codes in particular circumstances where the status codes SHALL map to particular states correctly, and only where the correct status code is not obvious. Other HTTP status codes may be used for other states as appropriate, and this particularly includes various authentication related status codes and redirects. Authentication redirects should not be interpreted to change the location of the resource itself. <br>

FHIR®  defines an OperationOutcome resource that can be used to convey specific detailed processable error information. For a few combinations of interactions and specific return codes, an OperationOutcome is required to be returned as the content of the response. The OperationOutcome may be returned with any HTTP 4xx or 5xx response, but is not required - many of these errors may be generated by generic server frameworks underlying a FHIR®  server.

<br>


## Gateway HTTP Response Codes

**Table: Gateway HTTP Response Codes**

|HTTP end point|HTTP verb|Scenario|HTTP response code|Notes|
|-
|DHDR end point| GET & POST |Authorization success|application dependent|Successfully authorized. Copy the code returned from the application.|
|DHDR end point| GET & POST |Authorization success|200| OK|
|DHDR end point| GET & POST | |201|Created|
|DHDR end point| GET & POST |Invalid token format|400|Bad Request|
|DHDR end point| GET & POST |Token information incorrect|401|Unauthorized|
|DHDR end point| GET & POST | Unauthorized|403|Forbidden|
|DHDR end point| GET & POST | Invalid Health Number|404|Not Found|
|DHDR end point| GET & POST | Unhandled exception|500|Server internal error|
|DHDR end point| Any other | |405|Method not allowed|


In all the cases above except for the successful authorization, Gateway will respond with appropriate FHIR response to the client using an OperationOutcome Resource (Ref. http://hl7.org/fhir/R4/operationoutcome.html). 

<br>


## IANA Defined HTTP Status Codes

http://www.iana.org/assignments/http-status-codes/http-status-codes.xhtml


The IANA HTTP Status Codes listed below describes HTTP responses that may be processed by the integration layer without accessing the OLIS solution. As a result, OperationOutcome resources would not be returned in these cases.

**Table: IANA-Defined HTTP Status Codes**



| Response Code | Description           | FHIR®  Usage Notes                                                                                       |
|---------------|-----------------------|----------------------------------------------------------------------------------------------------------|
| 200           | OK                    |   
| 201           | Created                    |                                                                                                                                                                                                            |
| 400           | Bad Request           | Resource could not be parsed or failed basic FHIR®  validation rules (or multiple matches were found for |
| 401         | Unauthorized          | |
| 403           | Forbidden            | Authorization is required for the interaction that was attempted                                                   |
| 404           | Not Found             | Resource type not supported, or not a FHIR®  end-point                                                   |
| 405           | Method Not Allowed    | The resource did not exist prior to the update, and the server does not allow client defined ids         |
| 422           | Unprocessable Entity   | The proposed resource violated applicable FHIR profiles or server business rules. Accompanied by an OperationOutcome resource providing additional detail.         |
| 500           | Internal Server Error |                                                                                                          |

