<p id="breadcrumb">

[Home](https://simplifier.net/guide/DigitalHealthDrugRepositoryHL7FHIRPointofCareSystemsAccessImplem/TableofContent) > Business Context > Use Case

</p>



# Use Cases


{{tree:ca-on-dhdr-r4/usecasediagram-duplicate-3}}
<font size="2">Ontario Health Digital Services DHDR Services Use Case Diagram </font>
<br>
 
## Business Scenario Category: Search and Read Medication Dispense Records

When an access request is made to the DHDR solution for a patient’s dispensed drug event history, the DHDR solution uniquely identifies the patient based on the supplied patient identifiers and returns that patient’s drug and pharmacy service events history to the calling system. The calling system can then use the results to create a drug and pharmacy service profile for the patient.

<br>

### <b>Transaction: Search Medication Dispense Request/Response</b>

#### <b> Medication Dispense Search </b>

<ul>The transactions will: <br><br>
<li>Allow a client application to search the DHDR repository for MedicationDispense records matching the search criteria </li>
<li> Allow the DHDR solution to return an appropriate set of MedicationDispense records </li>
</ul>
{{tree:ca-on-dhdr-r4/retrieve-medication-transaction-flow}}
<font size="2">Search Medication Treansaction </font>

<br>


#### <b> Use Case Category: Search Medication Dispense </b>

<br>  
This describes the use case category for searching for medication dispense information, based on a patient’s Health
Number, and optional search criteria. Please note that in the current release, Health Number is the only patient
identifier supported for searches, but in the future releases, multiple identifier types might be allowed as query
parameters, e.g. a point of care system might get all identifiers associated with a patient from the Provincial Client
Registry or from a local EMPI and then search DHDR for all dispenses of a patient using these identifiers.

Search Types: Search by Health Number (and optional Gender, Date of Birth & range of dispense dates)

Scenario Details: The User of the client application requests retrieval of medication dispense information, using
Health Number and optional search criteria as query parameters.

Message Flow:
<ol>
<li> “GET” or “POST” MedicationDispense search request is sent from the client application to DHDR (via the Gateway), containing query criteria in the URL string.
<li> DHDR (via the Gateway) responds with the search results, in the form of a FHIR Bundle response.
</ol> 

Alternate Flow of Events:
<ol>
<li> Unable to process the request due to a system-related or business-related issue, the Gateway responds with an HTTP status code, and optionally an OperationOutcome resource.
<li> If no MedicationDispense records are found within the default or the specified date range, then the Gateway will return a bundle with zero search results.
<li> Some or all search results are blocked by a patient Consent Directive. The response message will include non-blocked search results, and additionally indicate that that blocked records may be available. See Section 2.3 for handling of Consent Directives and Temporary Consent Unblock.
</ol>

<br>

### <b>Transaction: Read Medication Dispense Request/Response</b>

#### <b> Medication Dispense Read </b>

<ul>The transactions will: <br><br>
<li> Allow a client application to request a specific medication dispense record by specifying a Dispense ID</li>
<li> Allow the DHDR solution to return the appropriate MedicationDispense record</li></ul>
The medication dispense record that is returned will contain the information about the type of medication dispensed,
the prescriber, the fulfilling pharmacist and the name of the pharmacy that dispensed it. <br>
{{tree:ca-on-dhdr-r4/read-medication-transation-flow}}
<font size="2">Retrieve Medication Treansaction </font>

#### <b> Use Case Category: Read Medication Dispense </b>

This describes the use case category for reading a specific medication dispense record, based on the DHDR Resource
ID of the Medication Dispense (typically captured from a prior search operation).

Scenario Details: The User of the client application requests retrieval of a specific medication dispense information,
using the DHDR Resource ID of the Medication Dispense.

Message Flow:
<ol>
<li> “GET” MedicationDispense is sent from the client application to DHDR (via the Gateway), containing the query criteria in the URL string.
<li> DHDR (via the Gateway) responds with the read result, in the form of a FHIR Resource response.
</ol>

Alternate Flow of Events:
<ol>
<li> Unable to process the request due to a system-related or business-related issue, the Ontario Health Provider Gateway responds with an HTTP status code, and optionally an OperationOutcome
resource.
</ol>


## Business Scenario Category: Create Temporary Consent Block

A Patient who has a consent withdrawal in place, visits a participating Health Care Provider and authorizes complete
and full access to their dispensed drug event history to that health information custodian. Please note that there is no
masking in DHDR as a dispense record can be blocked or allowed but cannot be partially masked.
<br>

### <b>Transaction: Create Temporary Consent Unblock for Medication Dispenses Blocked by Consent Directives </b>

<font size="2.5"><b> Consent Unblock Request </b></font>

After receiving a Medication Dispense Response identifying the existence of records blocked by a consent directive, the user may request access to those blocked records by using the client application to send a Temporary Consent Unblock Request to the  Gateway. The request is submitted under the user’s “Under Authority Of (UAO) organization and allows all users of the UAO organization access to the patient’s blocked records for the subsequent four hours.

</ul>
{{tree:ca-on-dhdr-r4/create-temporary-consent-block}}
<font size="2"> Create Temporary Consent Block </font> 

#### <b> Use Case Category: Create Temporary Consent Unblock </B> </font>

Scenario Details: The User of the client application requests retrieval of medication dispense information. The response from DHDR indicates additional records are available but are blocked by the patient’s consent directive. The User obtains permission from the patient or the patient’s substitute decision maker (SDM) to temporarily unblock their record, captures approval via the official DHDR Temporary Unblocking of Access form, then stores the paper form securely for audit. The client application will prompt the User to confirm that permission has been obtained.

Message Flow:
<ol>
<li> A “GET” or “POST” MedicationDispense search request is sent from the client application to the Gateway, containing query criteria in the URL string.
<li> The DHDR solution (via the Gateway) responds with a FHIR Bundle response, with zero or more search results. The response indicates records are available but are blocked by the patient’s consent directives.
<li> The client application launches the Provincial Consent Override Interface (PCOI) Viewlet (hosted on an Ontario Health webserver), returning a web-based user interface.
<li> The user follows the prompts on the PCOI Viewlet, which include a PDF form for audit, and will receive a confirmation of successful temporary consent unblock through the viewlet.
<li> The client application resubmits the retrieval of medication dispense information.
</ol>

Alternate Flow of Events:
<ol>
<li> A User tries to access drug information when another user from the same organization had already obtained temporary consent unblock from the patient or SDM within the past four-hour time frame. The point of care system displays a notification to the user that consent has temporarily been unblock (messaging mechanism to identify MedicationDispense records as “temporarily consent unblocked” being finalized).

